==> huaweicloudsdkgaussdbfornosql-3.1.137-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/show_redis_pitr_info_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowRedisPitrInfoResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'storage': 'str'
    }

    attribute_map = {
        'storage': 'storage'
    }

    def __init__(self, storage=None):
        """ShowRedisPitrInfoResponse

        The model defined in huaweicloud sdk

        :param storage: 查询Redis实例指定时间点恢复所占用的存储空间。 单位：GB
        :type storage: str
        """
        
        super(ShowRedisPitrInfoResponse, self).__init__()

        self._storage = None
        self.discriminator = None

        if storage is not None:
            self.storage = storage

    @property
    def storage(self):
        """Gets the storage of this ShowRedisPitrInfoResponse.

        查询Redis实例指定时间点恢复所占用的存储空间。 单位：GB

        :return: The storage of this ShowRedisPitrInfoResponse.
        :rtype: str
        """
        return self._storage

    @storage.setter
    def storage(self, storage):
        """Sets the storage of this ShowRedisPitrInfoResponse.

        查询Redis实例指定时间点恢复所占用的存储空间。 单位：GB

        :param storage: The storage of this ShowRedisPitrInfoResponse.
        :type storage: str
        """
        self._storage = storage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowRedisPitrInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdbfornosql-3.1.148-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/show_redis_pitr_info_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowRedisPitrInfoResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'storage': 'str'
    }

    attribute_map = {
        'storage': 'storage'
    }

    def __init__(self, storage=None):
        r"""ShowRedisPitrInfoResponse

        The model defined in huaweicloud sdk

        :param storage: 查询Redis实例指定时间点恢复所占用的存储空间。 单位：GB
        :type storage: str
        """
        
        super(ShowRedisPitrInfoResponse, self).__init__()

        self._storage = None
        self.discriminator = None

        if storage is not None:
            self.storage = storage

    @property
    def storage(self):
        r"""Gets the storage of this ShowRedisPitrInfoResponse.

        查询Redis实例指定时间点恢复所占用的存储空间。 单位：GB

        :return: The storage of this ShowRedisPitrInfoResponse.
        :rtype: str
        """
        return self._storage

    @storage.setter
    def storage(self, storage):
        r"""Sets the storage of this ShowRedisPitrInfoResponse.

        查询Redis实例指定时间点恢复所占用的存储空间。 单位：GB

        :param storage: The storage of this ShowRedisPitrInfoResponse.
        :type storage: str
        """
        self._storage = storage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowRedisPitrInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
